import React, { useEffect, useState } from 'react';
import SearchResults from './search-results';

import { Button, Input, Col, Row } from 'antd';
import { SearchOutlined } from '@ant-design/icons';

const Search = () => {

    const INITIAL_STATE = { searchQuery: '', facets: [], filters: null };

    const [payload, setPayload] = useState(INITIAL_STATE);
    const [searchResults, setSearchResults] = useState([]);
    const [facets, setfacets] = useState([]);

    const handleOnChange = (e) => {
        setPayload(prevState => ({
            ...prevState,
            searchQuery: e.target.value,
            filters: null
        }));
    };

    const handleOnSearch = async () => {
        const { searchQuery, facets, filters } = payload;
        if (searchQuery) {
            const apiEndpoint = 'https://api-dot-abs-poc-np-prj-01-3f2a.uc.r.appspot.com';
            const url =  `${apiEndpoint}/search?text=${searchQuery}${facets.length? `&facets=${JSON.stringify(facets)}` : ''}${filters && Object.keys(filters).length? `&filters=${JSON.stringify(filters)}` : ''}`;  
            const searchResults = await fetch(url)
                .then(res => res.json())
                .catch(err => console.log(err));
            setSearchResults(searchResults.results?.length ? [...searchResults.results] : []);
            !Object.keys(filters || {}).length && setfacets(searchResults.facets?.length ? [...searchResults.facets] : []); // for not updating facets while filtering
        }
    };

    const handleImageClick = () => {
        setPayload(INITIAL_STATE);
        setSearchResults([]);
        setfacets([]);
    };

    const onSelectFacet = (val) => {
        setPayload(prevState => ({
            ...prevState,
            facets: val,
        }));
    }

    const onSelectFilter = (val) => {
        setPayload(prevState => ({
            ...prevState,
            filters: val,
        }));
    }

    useEffect(() => {
        if (payload.filters != null) {
            handleOnSearch();
        }
    }, [payload.filters])

    useEffect(() => {
        payload.facets.length ? handleOnSearch() : setfacets([]);
    }, [payload.facets])



    return (
        <>
            {searchResults.length > 0 &&
                <>
                    <div>
                        <Row style={{
                            alignItems: 'center'
                        }}
                        >
                            <Col span={5} style={{
                                margin: '1rem'
                            }}
                            >
                                <span style={{
                                    margin: '1rem 0',
                                    height: 'auto',
                                }}
                                    onClick={() => handleImageClick()}
                                >
                                    <img src='ultabeauty.png' alt="google" style={{
                                    }}
                                    />
                                </span>
                            </Col>
                            <Col span={12} style={{
                                margin: '0 1rem'
                            }}
                            >
                                <Input
                                    size='large'
                                    placeholder="Input Search Text"
                                    value={payload.searchQuery}
                                    allowClear
                                    prefix={<SearchOutlined style={{ color: "#d9d9d9", margin: '0 0.5rem' }} />}
                                    onChange={handleOnChange}
                                    onPressEnter={() => handleOnSearch()}
                                />
                            </Col>
                        </Row>
                    </div>
                    <SearchResults searchResults={searchResults} facets={facets}
                        onSelectFacet={(val) => onSelectFacet(val)}
                        onSelectFilter={(val) => onSelectFilter(val)}
                    />
                </>
            }
            {searchResults.length === 0 &&
                <div style={{
                    textAlign: 'center',
                    marginTop: '1rem',
                    top: '50%'
                }}>
                    <Row>
                        <Col span={12} offset={6}>
                            <div className='App'>
                                <span>
                                    <img src='ultabeauty.png' alt="google" style={{
                                        width: '12rem',
                                        height: 'auto',
                                        marginBottom: '2rem'
                                    }}
                                    />
                                </span>

                                <Input
                                    size='large'
                                    placeholder="Input Search Text"
                                    value={payload.searchQuery}
                                    allowClear
                                    prefix={<SearchOutlined style={{ color: "#d9d9d9", margin: '0 0.5rem' }} />}
                                    onChange={handleOnChange}
                                    onPressEnter={() => handleOnSearch()}
                                />
                                <Button type='primary' style={{
                                    margin: '2rem 1rem',
                                    minWidth: '7rem',
                                    minHeight: '2.5rem',
                                    background: '#b5904a'
                                }}
                                    onClick={() => handleOnSearch()}
                                > Search </Button>
                            </div>
                        </Col>
                    </Row>
                </div>
            }
        </>
    )
}

export default Search;